Contribute
==========

Please submit a pull requests to the `cibyl project`_ on GitHub.

.. _`cibyl project`: https://github.com/rhos-infra/cibyl


Style
-----

Cibyl CI enforces code linting according to the Google Python Style Guide

.. _`Python Style Guide`: https://google.github.io/styleguide/pyguide.html
